@@ -166,7 +166,7 @@ def print_result(besth, bestk, maxhsig, maxksig, print_comment=True):
 
 def hksta(hpara, isplot=False, isdisplay=False):
     station = basename(hpara.rfpath)
-    stadata = SACStation(join(hpara.rfpath, station+'finallist.dat'), only_r=True)
+    stadata = SACStation(hpara.rfpath, only_r=True)
     stack, _, allstack, _ = hkstack(stadata.datar, stadata.shift, stadata.sampling, srad2skm(stadata.rayp),
                                     hpara.hrange, hpara.krange, vp=hpara.vp, weight=hpara.weight)
     besth, bestk, cvalue, maxhsig, maxksig = ci(allstack, hpara.hrange, hpara.krange, stadata.ev_num)
@@ -178,7 +178,7 @@ def hksta(hpara, isplot=False, isdisplay=False):
     if isdisplay:
         print_result(besth, bestk, maxhsig, maxksig, print_comment=True)
     if isplot:
-        img_path = join(hpara.hkpath, station+'.pdf')
+        img_path = join(hpara.hkpath, station+'_Hk.pdf')
         plot(stack, allstack, hpara.hrange, hpara.krange, besth, bestk, cvalue, title=title, path=img_path)
     else:
         plot(stack, allstack, hpara.hrange, hpara.krange, besth, bestk, cvalue, title=title)
@@ -191,8 +191,6 @@ def hk():
                         # dest='station', type=str, default='')
     # parser.add_argument('-H', help='Range for searching best H: <hmin>/<hmax>', type=str, default='')
     # parser.add_argument('-K', help='Range for searching best K: <kmin>/<kmax>', type=str, default='')
-    parser.add_argument('-p', help='Whether to save the image',
-                        dest='isplot', action='store_true')
     parser.add_argument('-v', help='Display results to standard output',
                         dest='isdisplay', action='store_true')
     arg = parser.parse_args()
@@ -205,7 +203,7 @@ def hk():
     # if arg.K != '':
     #     kmin, kmax = [float(val) for val in arg.K.split('/')]
     #     hpara.krange = np.arange(kmin, kmax, 0.1)
-    hksta(hpara, isplot=arg.isplot, isdisplay=arg.isdisplay)
+    hksta(hpara, isplot=True, isdisplay=arg.isdisplay)
 
 
 def hktest():
