@@ -46,14 +46,28 @@ class SACStationS():
 class SACStation(object):
     def __init__(self, data_path, only_r=False):
         """
-        :param evt_lst: event list in RF data dir. Column as date string, phase, evt lat, evt lon, evt dep,
-                        distance, back-azimuth, ray parameter, magnitude and gauss factor.
+        Class for derivative process of RFs.
+
+        :param data_path: Path to RF data with SAC format. A finallist.dat must be in this path.
+        :type data_path: str
+        :param only_r: [description], defaults to False
+        :type only_r: bool, optional
+
+        .. warning::
+
+            This Class will be renamed to ``RFStation`` in future versions.
         """
         self.only_r = only_r
         if isfile(data_path):
             data_path = dirname(data_path)
         self.staname = basename(data_path)
-        evt_lst = join(data_path, self.staname+'finallist.dat')
+        evt_lsts = glob.glob(join(data_path, '*finallist.dat'))
+        if len(evt_lsts) == 0:
+            raise FileNotFoundError("No such *finallist.dat in the {}".format(data_path))
+        elif len(evt_lsts) > 1:
+            raise ValueError("More than one finallist.dat in the {}".format(data_path))
+        else:
+            evt_lst = evt_lsts[0]
         dtype = {'names': ('evt', 'phase', 'evlat', 'evlon', 'evdep', 'dis', 'bazi', 'rayp', 'mag', 'f0'),
                  'formats': ('U20', 'U20', 'f4', 'f4', 'f4', 'f4', 'f4', 'f4', 'f4', 'f4')}
         self.event, self.phase, self.evla, self.evlo, self.evdp, self.dis, self.bazi, self.rayp, self.mag, self.f0 = \
@@ -62,7 +76,12 @@ class SACStation(object):
         # self.phase = [ph.decode() for ph in self.phase]
         self.rayp = skm2srad(self.rayp)
         self.ev_num = self.evla.shape[0]
-        sample_sac = SACTrace.read(join(data_path, self.event[0] + '_' + self.phase[0] + '_R.sac'))
+        try:
+            sample_sac = SACTrace.read(join(data_path, self.event[0] + '_' + self.phase[0] + '_R.sac'))
+            self.comp = 'R'
+        except:
+            sample_sac = SACTrace.read(join(data_path, self.event[0] + '_' + self.phase[0] + '_Q.sac'))
+            self.comp = 'Q'
         self.stla = sample_sac.stla
         self.stlo = sample_sac.stlo
         self.rflength = sample_sac.npts
@@ -74,15 +93,22 @@ class SACStation(object):
         if not only_r:
             self.datat = np.empty([self.ev_num, self.rflength])
             for _i, evt, ph in zip(range(self.ev_num), self.event, self.phase):
-                sac = SACTrace.read(join(data_path, evt + '_' + ph + '_R.sac'))
+                sac = SACTrace.read(join(data_path, evt + '_' + ph + '_{}.sac'.format(self.comp)))
                 sact = SACTrace.read(join(data_path, evt + '_' + ph + '_T.sac'))
                 self.datar[_i] = sac.data
                 self.datat[_i] = sact.data
         else:
             for _i, evt, ph in zip(range(self.ev_num), self.event, self.phase):
-                sac = SACTrace.read(join(data_path, evt + '_' + ph + '_R.sac'))
+                sac = SACTrace.read(join(data_path, evt + '_' + ph + '_{}.sac'.format(self.comp)))
                 self.datar[_i] = sac.data
 
+    def normalize(self):
+        maxamp = np.nanmax(np.abs(self.datar), axis=1)
+        for i in range(self.ev_num):
+            self.datar[i] /= maxamp[i]
+            if not self.only_r:
+                self.datat[i] /= maxamp[i]
+
     def resample(self, dt):
         npts = int(self.rflength * (self.sampling / dt)) + 1
         self.datar = resample(self.datar, npts, axis=1)
@@ -90,6 +116,7 @@ class SACStation(object):
             self.datat = resample(self.datat, npts, axis=1)
         self.sampling = dt
         self.rflength = npts
+        self.time_axis = np.arange(npts) * dt - self.shift
 
     def moveoutcorrect(self, ref_rayp=0.06, dep_range=np.arange(0, 150), velmod='iasp91'):
         rf_corr, _ = moveoutcorrect_ref(self, skm2srad(ref_rayp), dep_range, velmod=velmod)
@@ -99,7 +126,7 @@ class SACStation(object):
         self.dep_range = dep_range
         rfdepth, _, _, _ = psrf2depth(self, dep_range, sampling=self.sampling, shift=self.shift, velmod=velmod, srayp=srayp)
         return rfdepth
-    
+
     def psrf_1D_raytracing(self, dep_range=np.arange(0, 150), velmod='iasp91', srayp=None):
         self.dep_range = dep_range
         pplat_s, pplon_s, _ , _, _, _, tpds = psrf_1D_raytracing(self, dep_range, velmod=velmod, srayp=srayp)
@@ -115,17 +142,29 @@ class SACStation(object):
         self.dep_range = dep_range
         mod3d = Mod3DPerturbation(mod3dpath, dep_range)
         pplat_s, pplon_s, pplat_p, pplon_p, raylength_s, raylength_p, Tpds = psrf_1D_raytracing(self, dep_range, velmod=velmod, srayp=srayp)
-        tps = psrf_3D_migration(pplat_s, pplon_s, pplat_p, pplon_p, raylength_s, raylength_p, Tpds, YAxisRange, mod3d)
+        tps = psrf_3D_migration(pplat_s, pplon_s, pplat_p, pplon_p, raylength_s, raylength_p, Tpds, dep_range, mod3d)
         rfdepth, _ = time2depth(self, dep_range, tps)
         return rfdepth
 
-    def jointani(self, tb, te, stack_baz_val=10, weight=[0.4, 0.3, 0.3]):
-        self.ani = RFAni(self, tb, te)
+    def jointani(self, tb, te, tlen=3, stack_baz_val=10, weight=[0.4, 0.4, 0.2]):
+        self.ani = RFAni(self, tb, te, tlen=tlen)
         self.ani.baz_stack(val=stack_baz_val)
         best_f, best_t = self.ani.joint_ani(weight=weight)
         return best_f, best_t
 
 
+class RFStation(SACStation):
+    def __init__(self, data_path, only_r):
+        """Class for derivative process of RFs.
+
+        :param data_path: Path to RF data with SAC format. A finallist.dat must be in this path.
+        :type data_path: str
+        :param only_r: [description], defaults to False
+        :type only_r: bool, optional
+        """
+        super().__init__(data_path, only_r=only_r)
+
+
 class DepModel(object):
     def __init__(self, YAxisRange, velmod='iasp91'):
         VelocityModel = np.loadtxt(from_file(velmod))
